@@ -9,23 +9,24 @@
 #'
 #' @param x A model object.
 #' @param dot_size,line_size Size of line and dot-geoms.
-#' @param panel Logical, if \code{TRUE}, plots are arranged as panels; else,
+#' @param panel Logical, if `TRUE`, plots are arranged as panels; else,
 #' single plots for each diagnostic are returned.
 #' @param check Character vector, indicating which checks for should be performed
-#'   and plotted. May be one or more of
-#'   \code{"all", "vif", "qq", "normality", "linearity", "ncv", "homogeneity", "outliers", "reqq"}.
-#'   \code{"reqq"} is a QQ-plot for random effects and only available for mixed
-#'   models.
-#'   \code{"ncv"} is an alias for \code{"linearity"}, and checks for non-constant
-#'   variance, i.e. for heteroscedasticity, as well as the linear relationship.
-#'   By default, all possible checks are performed and plotted.
+#'   and plotted. May be one or more of `"all"`, `"vif"`, `"qq"`, `"normality"`,
+#'   `"linearity"`, `"ncv"`, `"homogeneity"`, `"outliers"`, `"reqq"`, `"pp_check"`,
+#'   `"binned_residuals"` or `"overdispersion"`, Not that not all check apply
+#'   to all type of models (see 'Details'). `"reqq"` is a QQ-plot for random
+#'   effects and only available for mixed models. `"ncv"` is an alias for
+#'   `"linearity"`, and checks for non-constant variance, i.e. for
+#'   heteroscedasticity, as well as the linear relationship. By default, all
+#'   possible checks are performed and plotted.
 #' @param alpha,dot_alpha The alpha level of the confidence bands and dot-geoms.
 #'   Scalar from 0 to 1.
 #' @param colors Character vector with color codes (hex-format). Must be of
 #'   length 3. First color is usually used for reference lines, second color
 #'   for dots, and third color for outliers or extreme values.
 #' @param theme String, indicating the name of the plot-theme. Must be in the
-#'   format \code{"package::theme_name"} (e.g. \code{"ggplot2::theme_minimal"}).
+#'   format `"package::theme_name"` (e.g. `"ggplot2::theme_minimal"`).
 #' @param detrend Should QQ/PP plots be detrended?
 #' @param verbose Toggle off warnings.
 #' @param ... Currently not used.
@@ -35,27 +36,32 @@
 #' @note This function just prepares the data for plotting. To create the plots,
 #'   \CRANpkg{see} needs to be installed. Furthermore, this function suppresses
 #'   all possible warnings. In case you observe suspicious plots, please refer
-#'   to the dedicated functions (like \code{check_collinearity()},
-#'   \code{check_normality()} etc.) to get informative messages and warnings.
+#'   to the dedicated functions (like `check_collinearity()`,
+#'   `check_normality()` etc.) to get informative messages and warnings.
+#'
+#' @details For Bayesian models from packages **rstanarm** or **brms**,
+#'   models will be "converted" to their frequentist counterpart, using
+#'   [`bayestestR::bayesian_as_frequentist`](https://easystats.github.io/bayestestR/reference/convert_bayesian_as_frequentist.html).
+#'   A more advanced model-check for Bayesian models will be implemented at a
+#'   later stage.
 #'
 #' @section Linearity Assumption:
-#' The plot \strong{Linearity} checks the assumption of linear relationship.
+#' The plot **Linearity** checks the assumption of linear relationship.
 #' However, the spread of dots also indicate possible heteroscedasticity (i.e.
-#' non-constant variance); hence, the alias \code{"ncv"} for this plot.
-#' \strong{Some caution is needed} when interpreting these plots. Although these
+#' non-constant variance); hence, the alias `"ncv"` for this plot.
+#' **Some caution is needed** when interpreting these plots. Although these
 #' plots are helpful to check model assumptions, they do not necessarily
 #' indicate so-called "lack of fit", e.g. missed non-linear relationships or
 #' interactions. Thus, it is always recommended to also look at
-#' \href{https://strengejacke.github.io/ggeffects/articles/introduction_partial_residuals.html}{effect
-#' plots, including partial residuals}.
+#' [effect plots, including partial residuals](https://strengejacke.github.io/ggeffects/articles/introduction_partial_residuals.html).
 #'
 #' @section Residuals for (Generalized) Linear Models:
 #' Plots that check the normality of residuals (QQ-plot) or the homogeneity of
 #' variance use standardized Pearson's residuals for generalized linear models,
 #' and standardized residuals for linear models. The plots for the normality of
 #' residuals (with overlayed normal curve) and for the linearity assumption use
-#' the default residuals for \code{lm} and \code{glm} (which are deviance
-#' residuals for \code{glm}).
+#' the default residuals for `lm` and `glm` (which are deviance
+#' residuals for `glm`).
 #'
 #' @examples
 #' \dontrun{
@@ -78,6 +84,9 @@ check_model <- function(x, ...) {
 }
 
 
+
+# default ----------------------------
+
 #' @rdname check_model
 #' @export
 check_model.default <- function(x,
@@ -120,10 +129,66 @@ check_model.default <- function(x,
   attr(ca, "detrend") <- detrend
   attr(ca, "colors") <- colors
   attr(ca, "theme") <- theme
+  attr(ca, "model_info") <- minfo
+  attr(ca, "overdisp_type") <- list(...)$plot_type
   ca
 }
 
 
+# methods ----------------------------------
+
+#' @export
+print.check_model <- function(x, ...) {
+  insight::check_if_installed("see", "for model diagnositic plots")
+  NextMethod()
+}
+
+#' @export
+plot.check_model <- function(x, ...) {
+  insight::check_if_installed("see", "for model diagnositic plots")
+  NextMethod()
+}
+
+
+
+# other classes ---------------------------
+
+## TODO for now, convert to freq, see https://github.com/easystats/performance/issues/354
+## need to fix this later
+
+#' @export
+check_model.stanreg <- function(x,
+                                dot_size = 2,
+                                line_size = .8,
+                                panel = TRUE,
+                                check = "all",
+                                alpha = .2,
+                                dot_alpha = .8,
+                                colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
+                                theme = "see::theme_lucid",
+                                detrend = FALSE,
+                                verbose = TRUE,
+                                ...) {
+  check_model(bayestestR::bayesian_as_frequentist(x),
+    dot_size = dot_size,
+    line_size = line_size,
+    panel = panel,
+    check = check,
+    alpha = alpha,
+    dot_alpha = dot_alpha,
+    colors = colors,
+    theme = theme,
+    detrend = detrend,
+    verbose = verbose,
+    ...
+  )
+}
+
+
+#' @export
+check_model.brmsfit <- check_model.stanreg
+
+
 #' @export
 check_model.model_fit <- function(x,
                                   dot_size = 2,
@@ -131,7 +196,11 @@ check_model.model_fit <- function(x,
                                   panel = TRUE,
                                   check = "all",
                                   alpha = .2,
+                                  dot_alpha = .8,
+                                  colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
+                                  theme = "see::theme_lucid",
                                   detrend = FALSE,
+                                  verbose = TRUE,
                                   ...) {
   check_model(
     x$fit,
@@ -140,14 +209,18 @@ check_model.model_fit <- function(x,
     panel = panel,
     check = check,
     alpha = alpha,
+    dot_alpha = dot_alpha,
+    colors = colors,
+    theme = theme,
     detrend = detrend,
+    verbose = verbose,
     ...
   )
 }
 
 
 
-
+# compile plots for checks of linear models  ------------------------
 
 .check_assumptions_linear <- function(model, model_info) {
   dat <- list()
@@ -165,14 +238,16 @@ check_model.model_fit <- function(x,
     threshold <- NULL
   }
   dat$INFLUENTIAL <- .influential_obs(model, threshold = threshold)
+  dat$PP_CHECK <- tryCatch(check_predictions(model), error = function(e) NULL)
 
-  dat <- .compact_list(dat)
+  dat <- insight::compact_list(dat)
   class(dat) <- c("check_model", "see_check_model")
   dat
 }
 
 
 
+# compile plots for checks of generalized linear models  ------------------------
 
 .check_assumptions_glm <- function(model, model_info) {
   dat <- list()
@@ -188,14 +263,22 @@ check_model.model_fit <- function(x,
     threshold <- NULL
   }
   dat$INFLUENTIAL <- .influential_obs(model, threshold = threshold)
+  dat$PP_CHECK <- tryCatch(check_predictions(model), error = function(e) NULL)
+  if (isTRUE(model_info$is_binomial)) {
+    dat$BINNED_RESID <- binned_residuals(model)
+  }
+  if (isTRUE(model_info$is_count)) {
+    dat$OVERDISPERSION <- .diag_overdispersion(model)
+  }
 
-  dat <- .compact_list(dat)
+  dat <- insight::compact_list(dat)
   class(dat) <- c("check_model", "see_check_model")
   dat
 }
 
 
 
+# compile plots for checks of Bayesian models  ------------------------
 
 .check_assumptions_stan <- function(model) {
   if (inherits(model, "brmsfit")) {
@@ -211,7 +294,7 @@ check_model.model_fit <- function(x,
     d2 <- brms::prior_samples(model)
 
     if (is.null(d2)) {
-      stop("No prior-samples found. Please use option `sample_prior = TRUE` when fitting the model.", call. = FALSE)
+      stop(insight::format_message("No prior-samples found. Please use option `sample_prior = TRUE` when fitting the model."), call. = FALSE)
     }
 
     d1 <- brms::posterior_samples(model)
@@ -247,20 +330,20 @@ check_model.model_fit <- function(x,
     # remove intercept from output for ridgeline plot.
     # this would increase the range of the scale too much
 
-    if (.obj_has_name(d1, "(Intercept)")) {
-      d1 <- .remove_column(d1, "(Intercept)")
+    if (insight::object_has_names(d1, "(Intercept)")) {
+      d1 <- datawizard::data_remove(d1, "(Intercept)")
     }
 
-    if (.obj_has_name(d2, "(Intercept)")) {
-      d2 <- .remove_column(d2, "(Intercept)")
+    if (insight::object_has_names(d2, "(Intercept)")) {
+      d2 <- datawizard::data_remove(d2, "(Intercept)")
     }
 
-    if (.obj_has_name(d1, "sigma")) {
-      d1 <- .remove_column(d1, "sigma")
+    if (insight::object_has_names(d1, "sigma")) {
+      d1 <- datawizard::data_remove(d1, "sigma")
     }
 
-    if (.obj_has_name(d2, "sigma")) {
-      d2 <- .remove_column(d2, "sigma")
+    if (insight::object_has_names(d2, "sigma")) {
+      d2 <- datawizard::data_remove(d2, "sigma")
     }
 
     d1 <- d1[, grepl(pattern = "^(?!(b\\[\\(Intercept\\)|Sigma\\[))(.*)", colnames(d1), perl = TRUE)]
