@@ -1,7 +1,8 @@
 # prepare data for VIF plot ----------------------------------
 
 .diag_vif <- function(model) {
-  dat <- insight::compact_list(check_collinearity(model))
+  out <- check_collinearity(model)
+  dat <- insight::compact_list(out)
   if (is.null(dat)) {
     return(NULL)
   }
@@ -9,13 +10,20 @@
   dat$group[dat$VIF >= 5 & dat$VIF < 10] <- "moderate"
   dat$group[dat$VIF >= 10] <- "high"
 
-  if (ncol(dat) == 5) {
-    colnames(dat) <- c("x", "y", "se", "facet", "group")
-    dat[, c("x", "y", "facet", "group")]
-  } else {
-    colnames(dat) <- c("x", "y", "se", "group")
-    dat[, c("x", "y", "group")]
+  dat <- datawizard::data_rename(
+    dat,
+    c("Term", "VIF", "SE_factor", "Component"),
+    c("x", "y", "se", "facet")
+  )
+
+  dat <- datawizard::data_select(dat, c("x", "y", "facet", "group"))
+
+  if (insight::n_unique(dat$facet) <= 1) {
+    dat$facet <- NULL
   }
+
+  attr(dat, "CI") <- attributes(out)$CI
+  dat
 }
 
 
