@@ -48,6 +48,8 @@ check_zeroinflation <- function(x, tolerance = .05) {
   if (model_info$is_negbin) {
     if (methods::is(x, "glmmTMB")) {
       theta <- stats::sigma(x)
+    } else if (methods::is(x, "glmerMod")) {
+      theta <- environment(x@resp$family$aic)[[".Theta"]]
     } else {
       theta <- x$theta
     }
@@ -73,3 +75,28 @@ check_zeroinflation <- function(x, tolerance = .05) {
     )
   )
 }
+
+
+
+# methods ------------------
+
+#' @export
+print.check_zi <- function(x, ...) {
+  insight::print_color("# Check for zero-inflation\n\n", "blue")
+  cat(sprintf("   Observed zeros: %i\n", x$observed.zeros))
+  cat(sprintf("  Predicted zeros: %i\n", x$predicted.zeros))
+  cat(sprintf("            Ratio: %.2f\n\n", x$ratio))
+
+  lower <- 1 - x$tolerance
+  upper <- 1 + x$tolerance
+
+  if (x$ratio < lower) {
+    message("Model is underfitting zeros (probable zero-inflation).")
+  } else if (x$ratio > upper) {
+    message("Model is overfitting zeros.")
+  } else {
+    message(insight::format_message("Model seems ok, ratio of observed and predicted zeros is within the tolerance range."))
+  }
+
+  invisible(x)
+}
