@@ -5,6 +5,13 @@ format.compare_performance <- function(x, digits = 2, ...) {
     x$Performance_Score <- insight::format_value(x$Performance_Score, as_percent = TRUE)
     x <- x[!sapply(x, anyNA)]
   }
+
+  # format weighted ICs
+  weighted_ics <- grepl("_wt$", colnames(x))
+  if (any(weighted_ics)) {
+    x[weighted_ics] <- lapply(x[weighted_ics], insight::format_bf, name = NULL)
+  }
+
   if ("BF" %in% colnames(x)) {
     x$BF[is.na(x$BF)] <- 1
     # x$BF <- insight::format_bf(x$BF)
