@@ -1,13 +1,14 @@
 #' @title Tjur's R2 - coefficient of determination (D)
 #' @name r2_tjur
 #'
-#' @description This method calculates the Coefficient of Discrimination \code{D}
+#' @description This method calculates the Coefficient of Discrimination `D`
 #'   (also known as Tjur's R2; \cite{Tjur, 2009}) for generalized linear (mixed) models
 #'   for binary outcomes. It is an alternative to other pseudo-R2 values like
-#'   Nagelkerke's R2 or Cox-Snell R2. The Coefficient of Discrimination \code{D}
+#'   Nagelkerke's R2 or Cox-Snell R2. The Coefficient of Discrimination `D`
 #'   can be read like any other (pseudo-)R2 value.
 #'
 #' @param model Binomial Model.
+#' @param ... Arguments from other functions, usually only used internally.
 #'
 #' @return A named vector with the R2 value.
 #'
@@ -17,10 +18,14 @@
 #' @references Tjur, T. (2009). Coefficients of determination in logistic regression models - A new proposal: The coefficient of discrimination. The American Statistician, 63(4), 366-372.
 #'
 #' @export
-r2_tjur <- function(model) {
+r2_tjur <- function(model, ...) {
+  if (is.null(info <- list(...)$model_info)) {
+    info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
+
   # check for valid object class
-  if (!insight::model_info(model, verbose = FALSE)$is_binomial) {
-    stop("`model` must be binomial.")
+  if (!info$is_binomial) {
+    stop("`model` must be binomial.", call. = FALSE)
   }
 
   y <- .recode_to_zero(insight::get_response(model, verbose = FALSE))
