@@ -5,9 +5,9 @@ test_bf <- function(...) {
 }
 
 
-#' @importFrom insight ellipsis_info
+#' @rdname test_performance
 #' @export
-test_bf.default <- function(...) {
+test_bf.default <- function(..., text_length = NULL) {
 
   # Attribute class to list and get names from the global environment
   objects <- insight::ellipsis_info(..., only_models = TRUE)
@@ -17,22 +17,21 @@ test_bf.default <- function(...) {
   .test_performance_checks(objects, multiple = FALSE)
 
   if (length(objects) == 1 && isTRUE(insight::is_model(objects))) {
-    stop("'test_bf()' is designed to compare multiple models together. For a single model, you might want to run bayestestR::bf_parameters() instead.", call. = FALSE)
+    stop(insight::format_message("'test_bf()' is designed to compare multiple models together. For a single model, you might want to run bayestestR::bf_parameters() instead."), call. = FALSE)
   }
 
   # If a suitable class is found, run the more specific method on it
   if (inherits(objects, c("ListNestedRegressions", "ListNonNestedRegressions", "ListLavaan"))) {
-    test_bf(objects)
+    test_bf(objects, text_length = text_length)
   } else {
-    stop("The models cannot be compared for some reason :/")
+    stop("The models cannot be compared for some reason :/", call. = FALSE)
   }
 }
 
 
 
-#' @importFrom bayestestR bayesfactor_models
 #' @export
-test_bf.ListModels <- function(objects, reference = 1, ...) {
+test_bf.ListModels <- function(objects, reference = 1, text_length = NULL, ...) {
   if (.test_bf_areAllBayesian(objects) == "mixed") {
     stop("You cannot mix Bayesian and non-Bayesian models in 'test_bf()'.", call. = FALSE)
   }
@@ -45,6 +44,12 @@ test_bf.ListModels <- function(objects, reference = 1, ...) {
   }
 
   rez <- bayestestR::bayesfactor_models(objects, denominator = ref)
+
+  # check for log-BF
+  if (!is.null(rez$log_BF)) {
+    rez$BF <- exp(rez$log_BF)
+  }
+
   row.names(rez) <- NULL
 
   # Adjust BFs for sequential testing
@@ -62,8 +67,12 @@ test_bf.ListModels <- function(objects, reference = 1, ...) {
     rez$BF[ref] <- NA
   }
 
+  # add log-BF
+  rez$log_BF <- log(rez$BF)
+
   # Replace denominator
   attr(rez, "denominator") <- ref
+  attr(rez, "text_length") <- text_length
   class(rez) <- c("bayesfactor_models", "see_bayesfactor_models", class(rez))
   rez
 }
@@ -72,9 +81,9 @@ test_bf.ListModels <- function(objects, reference = 1, ...) {
 
 # Helpers -----------------------------------------------------------------
 
-#' @importFrom insight model_info
 .test_bf_areAllBayesian <- function(objects) {
   bayesian_models <- sapply(objects, function(i) isTRUE(insight::model_info(i)$is_bayesian))
+
   if (all(bayesian_models == TRUE)) {
     "yes"
   } else if (all(bayesian_models == FALSE)) {
